from setuptools import setup, find_packages

setup(
    author="minamorl",
    author_email="minamorl@minamorl.com",
    name="trishula",
    url="https://github.com/minamorl/trishula",
    version="0.0.2",
    packages=find_packages(),
)
